White Renamer is a software that ease the pain of renaming multiple files and folders by doing it in batch. The user can choose many actions to perform on the selected directory. The following sections describes what those actions are, and how to use it.

White Renamer has a simple UI containing two distinct parts : the top part displays boxes representing the structure of the files (file + extension or folder). 
Some optional boxes can be inserted : Prefix and Suffix that give the possiblity to add prefix(es) or suffix(es) to the filename.
The bottom part displays a live preview of the changes made to the files/folders.

For more information, please read the documentation under whiterenamer/doc/Documentation.pdf
